# "fix" underlinking:
%define _disable_ld_no_undefined 1

%global giturl  https://github.com/garrigue/lablgtk

Name:           ocaml-lablgtk2
Version:        2.18.14
Release:        %mkrel 2
Summary:        OCaml interface to the GIMP Tool Kit Version 2
# The project as a whole is LGPL-2.0-only.  LGPL-2.1-or-later files:
# - src/gtkSourceView2_types.mli
# - src/introspection/xml-light/* (not included in the binary RPM)
License:        LGPL-2.0-only WITH OCaml-LGPL-linking-exception AND LGPL-2.1-or-later WITH OCaml-LGPL-linking-exception
Group:          Development/OCaml
URL:            https://garrigue.github.io/lablgtk/
VCS:            git:%{giturl}.git
Source:         %{giturl}/archive/%{version}/lablgtk-%{version}.tar.gz
# Provide a definition of ml_rsvg_handle_new_gz for newer versions of librsvg
# which do not explicitly expose an SVGZ interface.
Patch:          ocaml-lablgtk-svgz.patch
# Adapt to new paths to Unix library in OCaml 5.1.0
Patch:          ocaml-lablgtk-unix.patch

BuildRequires:  help2man
BuildRequires:  ocaml >= 4.06
BuildRequires:  ocaml-camlp-streams-devel
BuildRequires:  ocaml-findlib >= 1.2.1
BuildRequires:  ocaml-ocamldoc
BuildRequires:  ocaml-rpm-macros
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtkspell-2.0)
BuildRequires:  pkgconfig(libglade-2.0)
BuildRequires:  pkgconfig(libgnomecanvas-2.0)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(zlib)

%global __ocaml_requires_opts -i GtkSourceView2_types


%description
LablGTK is an Objective Caml interface to gtk+.

It uses the rich type system of Objective Caml to provide a strongly
typed, yet very comfortable, object-oriented interface to gtk+. This
is not that easy if you know the dynamic typing approach taken by
gtk+.


%package devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       gtk2-devel

%description devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.


%prep
%autosetup -n lablgtk-%{version} -p1

# Remove spurious executable bits
chmod a-x README*

%build
# Parallel builds don't work.
unset MAKEFLAGS
%configure --without-gnomeui
sed -e "s|-O|%{build_cflags}|" \
    -e "s|-shared|& -ccopt '%{build_ldflags}'|" \
    -e "s|(CAMLMKLIB)|& -ldopt '%{build_ldflags}'|" \
    -e "s|-warn-error [-A-Za-z0-9]\+||" \
    -i src/Makefile
%ifarch %{ocaml_native_compiler}
make world CAMLOPT="ocamlopt.opt -g" CAMLC="ocamlc.opt -g"
%else
make world CAMLC="ocamlc -g"
%endif


%install
export DESTDIR=$RPM_BUILD_ROOT
export OCAMLFIND_DESTDIR=$RPM_BUILD_ROOT%{ocamldir}
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_libdir}
mkdir -p $RPM_BUILD_ROOT%{ocamldir}/lablgtk2
mkdir -p $RPM_BUILD_ROOT%{ocamldir}/stublibs
make install \
     RANLIB=true \
     BINDIR=$RPM_BUILD_ROOT%{_bindir} \
     LIBDIR=$RPM_BUILD_ROOT%{_libdir} \
     INSTALLDIR=$RPM_BUILD_ROOT%{ocamldir}/lablgtk2 \
     DLLDIR=$RPM_BUILD_ROOT%{ocamldir}/stublibs
%ifarch %{ocaml_native_compiler}
cp -p META $RPM_BUILD_ROOT%{ocamldir}/lablgtk2
%else
# Do not require the native artifacts
sed -e '/native/d' \
    -e '/exists_if/s/,[[:alnum:]]*\.cmxa,[[:alnum:]]*\.cmxs//' \
    -e '/exists_if/s/,[[:alnum:]]*\.cmx//' \
    META > $RPM_BUILD_ROOT%{ocamldir}/lablgtk2/META
touch -r META $RPM_BUILD_ROOT%{ocamldir}/lablgtk2/META
%endif

# Remove ld.conf (part of main OCaml dist).
rm $RPM_BUILD_ROOT%{ocamldir}/ld.conf

# Remove unnecessary *.ml files (ones which have a *.mli).
pushd $RPM_BUILD_ROOT%{ocamldir}/lablgtk2
for f in *.ml; do \
  b=`basename $f .ml`; \
  if [ -f "$b.mli" ]; then \
    rm $f; \
  fi; \
done
popd

# Remove .cvsignore files from examples directory.
find examples -name .cvsignore -delete

# Generate man pages
export LD_LIBRARY_PATH=$PWD/src
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
cp -p src/lablgladecc src/lablgladecc2
for bin in gdk_pixbuf_mlsource lablgladecc2 lablgtk2; do
  help2man -N --version-string=%{version} src/$bin > \
    $RPM_BUILD_ROOT%{_mandir}/man1/$bin.1
done

%ocaml_files

# Move two files from the main package to the devel package
sed -i '/propcc/d;/varcc/d' .ofiles


%files -f .ofiles


%files devel -f .ofiles-devel
%doc CHANGES.API
%{ocamldir}/lablgtk2/propcc
%{ocamldir}/lablgtk2/varcc



%changelog
* Sat Apr 05 2025 pterjan <pterjan> 2.18.14-2.mga10
+ Revision: 2173778
- Fix dfependency

* Sat Apr 05 2025 pterjan <pterjan> 2.18.14-1.mga10
+ Revision: 2173730
- Update to 2.18.14

* Wed Jul 17 2024 pterjan <pterjan> 2.18.13-2.mga10
+ Revision: 2081886
- Drop libgnomeui-2.0 support, nothing requires ocaml(GnomeDruid)
- Drop some useless requirements on gtksourceview-3.0. (Switching the lines from gtksourceview-2.0 to gtksourceview-3.0 in r1592237 was wrong, lablgtk2 has bindings only for gtksourceview-1.0 and gtksourceview-2.0 so will never make use of gtksourceview-3.0)

* Thu Oct 20 2022 pterjan <pterjan> 2.18.13-1.mga9
+ Revision: 1898075
- Update to 2.18.13

* Wed May 18 2022 pterjan <pterjan> 2.18.11-5.mga9
+ Revision: 1858762
- Rebuild for OCaml 4.14

* Wed Apr 06 2022 umeabot <umeabot> 2.18.11-4.mga9
+ Revision: 1845854
- Mageia 9 Mass Rebuild

* Tue Oct 12 2021 tv <tv> 2.18.11-3.mga9
+ Revision: 1750773
- "fix" underlinking
- Use our flags
- Drop -warn-error from flags
  It breaks the build on OCaml 4.13 because of new warnings
- Rebuild for ocaml 4.13.1

* Wed Mar 03 2021 tv <tv> 2.18.11-2.mga9
+ Revision: 1696723
- rebuild for ocaml-4.2-12

* Wed Mar 03 2021 tv <tv> 2.18.11-1.mga9
+ Revision: 1696558
- 2.18.11

* Thu Jun 11 2020 joequant <joequant> 2.18.10-4.mga8
+ Revision: 1592237
- add no-common for gcc10

* Fri Feb 28 2020 umeabot <umeabot> 2.18.10-3.mga8
+ Revision: 1551144
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 2.18.10-2.mga8
+ Revision: 1544317
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 tv <tv> 2.18.10-1.mga8
+ Revision: 1482841
- new release + rebuild for ocaml-4.10

* Sun Jan 19 2020 tv <tv> 2.18.8-1.mga8
+ Revision: 1481543
- new release + rebuild for ocaml-4.10
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 23 2018 pterjan <pterjan> 2.18.6-6.mga7
+ Revision: 1324539
- Rebuild for ocaml 4.07.1

* Sun Sep 23 2018 umeabot <umeabot> 2.18.6-5.mga7
+ Revision: 1299885
- Mageia 7 Mass Rebuild

* Sat May 12 2018 eatdirt <eatdirt> 2.18.6-4.mga7
+ Revision: 1228602
- Rebuild to fix missing signature

* Thu Apr 26 2018 daviddavid <daviddavid> 2.18.6-3.mga7
+ Revision: 1222525
- fix requires

* Sun Nov 26 2017 tv <tv> 2.18.6-2.mga7
+ Revision: 1179355
- fix deps

* Sun Nov 26 2017 tv <tv> 2.18.6-1.mga7
+ Revision: 1179346
- BR ncurses-devel
- new release
- rebuild for new ocaml

* Fri Oct 06 2017 daviddavid <daviddavid> 2.18.3-3.mga7
+ Revision: 1169538
- enable debugging information thus fixing empty debugsourcefiles.list

* Mon Sep 26 2016 pterjan <pterjan> 2.18.3-2.mga6
+ Revision: 1056402
- Rebuild for fix in ocaml

* Mon Feb 01 2016 pterjan <pterjan> 2.18.3-1.mga6
+ Revision: 930653
- Fix BuildRequires
- Update to 2.18.3

* Mon Oct 05 2015 eatdirt <eatdirt> 2.18.0-6.mga6
+ Revision: 886271
- Rebuild for ocaml-lablgl

* Wed Oct 15 2014 umeabot <umeabot> 2.18.0-5.mga5
+ Revision: 740152
- Second Mageia 5 Mass Rebuild

* Tue Sep 23 2014 malo <malo> 2.18.0-4.mga5
+ Revision: 722337
- fix auto requires

* Tue Sep 16 2014 umeabot <umeabot> 2.18.0-3.mga5
+ Revision: 683055
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 2.18.0-2.mga4
+ Revision: 539204
- Mageia 4 Mass Rebuild

* Sat Oct 05 2013 malo <malo> 2.18.0-1.mga4
+ Revision: 491620
- new version 2.18.0
- add patch to build documentation

* Sat Sep 07 2013 blue_prawn <blue_prawn> 2.16.0-8.mga4
+ Revision: 475796
- rebuild for ocaml-4.01.0

* Sun Jan 13 2013 umeabot <umeabot> 2.16.0-7.mga3
+ Revision: 361423
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Oct 18 2012 malo <malo> 2.16.0-6.mga3
+ Revision: 308020
- rebuild for ocaml-4.0.1

* Tue Oct 02 2012 blue_prawn <blue_prawn> 2.16.0-5.mga3
+ Revision: 302034
- build requires ocaml-compiler-libs
- rebuild for new ocaml 4.00

* Sat Sep 29 2012 blue_prawn <blue_prawn> 2.16.0-4.mga3
+ Revision: 300406
- new rpm group for ocaml

* Sun Aug 26 2012 blue_prawn <blue_prawn> 2.16.0-3.mga3
+ Revision: 284370
- corrected group for documentation

* Sun Aug 26 2012 blue_prawn <blue_prawn> 2.16.0-2.mga3
+ Revision: 284190
- build requires findlib
- switched from the old make old-install target to the new make install that uses ocamlfind install

* Sat Aug 25 2012 blue_prawn <blue_prawn> 2.16.0-1.mga3
+ Revision: 283996
- removed old fixes for the META files
- updated to last version 2.16.0

* Sat Feb 18 2012 malo <malo> 2.14.2-5.mga2
+ Revision: 210152
- Missing requires.
- missing explicit BuildRequires.

* Sun Oct 02 2011 fwang <fwang> 2.14.2-4.mga2
+ Revision: 150919
- rebuild

* Sun Sep 18 2011 fwang <fwang> 2.14.2-3.mga2
+ Revision: 144942
- rebuild
- tweak br

* Sat Jul 02 2011 fwang <fwang> 2.14.2-2.mga2
+ Revision: 117453
- build without gnome-panel

* Tue Feb 22 2011 mikala <mikala> 2.14.2-1.mga1
+ Revision: 56480
- Remove BuildRoot
- imported package ocaml-lablgtk2

